@@ -37,7 +37,6 @@ def _handle_ex_ret(code_list=['00700'], queryType=None, start_date=None, end_dat
 
         day_count = (e_dt - s_dt).days
         if day_count > 365 * 1: return '您好,技术指标接口一次最多只能提供1年的数据哟,如果需要更多的数据,请分段获取!'
-    print('start_date:{}, end_date:{}'.format(start_date, end_date))
 
     body = {
         "codeList": code_list,
@@ -50,9 +49,8 @@ def _handle_ex_ret(code_list=['00700'], queryType=None, start_date=None, end_dat
         "current": page,
         "size": 100
     }
-    print('body:{}'.format(body))
     df_ = total_handle_req(body=body, URL=BE_TECH_POST_URL)
-    print('--->df_:{}'.format(df_))
+
     return df_
 
 ###### 基础类技术面指标
@@ -109,11 +107,13 @@ def get_boll_factor_data(code_list=['00700'], market=2, unit='1d', start_date=No
             fre:是否复权  1 不复权/2 前复权/3 后复权
         Returns: 返回因子数据
         '''
-    factor_names = ['SecuCode', 'MID', 'MD', 'UPPERValue', 'LOWERValue', 'TradingDay']
+    factor_names = ['SecuCode', 'MID', 'UPPERValue', 'LOWERValue', 'TradingDay']
     data_type = 'tradition'
-    # f_data_ = _handle_ex_ret(code_list, data_type, start_date, end_date, market, unit, 1, fre)
-    # __ = _get__(f_data_, factor_names, data_type, code_list, start_date, end_date, market, unit, fre)
     __ = total_cls_handle(code_list, factor_names, data_type, start_date, end_date, market, unit, fre)
+    try:
+        __.columns = ['SecuCode', 'MidLine', 'UpLine', 'DownLine', 'TradingDay']
+    except:
+        return __
     return __
 
 def get_wr_factor_data(code_list=['00700'], market=2, unit='1d', start_date=None, end_date=None, fre=2):
@@ -291,7 +291,7 @@ def get_hsigma_factor_data(code_list=['00700'], market=2, unit='1d', start_date=
     __ = total_cls_handle(code_list, factor_names, data_type, start_date, end_date, market, unit, fre)
     return __
 
-def get_hmsens_factor_data(code_list=['00700'], market=2, unit='1d', start_date=None, end_date=None, fre=2):
+def get_dmsens_factor_data(code_list=['00700'], market=2, unit='1d', start_date=None, end_date=None, fre=2):
     '''
         获取Dmsens技术指标数据
         Args:
@@ -516,10 +516,11 @@ def get_strev_factor_data(code_list=['00700'], market=2, unit='1d', start_date=N
 def total_cls_handle(code_list, factor_names, data_type=None, start_date=None, end_date=None, market=None, unit=None, fre=None):
     # 统一处理返回值
     try:
+
         code_list = list(set(code_list))
         f_data_ = _handle_ex_ret(code_list, data_type, start_date, end_date, market, unit, 1, fre)
-        print('f_data_:{}'.format(f_data_))
-        if t_typeof(f_data_) == 'str': return f_data_
+
+        if t_typeof(f_data_) == 'str' or '您好' in f_data_ or '抱歉' in f_data_: return f_data_
         if [] == f_data_['result']:
             return '您好, 检测到时间区间的存在问题, 导致取到的数据为空, 请修改时间后重新请求数据.'
 
